@@ -79,7 +79,7 @@ void remmina_rdp_OnChannelConnectedEventHandler(rdpContext* context, ChannelConn
 		if (rfi->scale == REMMINA_PROTOCOL_WIDGET_SCALE_MODE_DYNRES) {
 			remmina_rdp_event_send_delayed_monitor_layout(rfi->protocol_widget);
 		}
-	}remmina_plugin_service->log_printf("Channel %s has been opened\n", e->name);
+	}REMMINA_PLUGIN_DEBUG("Channel %s has been opened", e->name);
 }
 
 void remmina_rdp_OnChannelDisconnectedEventHandler(rdpContext* context, ChannelConnectedEventArgs* e)
@@ -91,6 +91,6 @@ void remmina_rdp_OnChannelDisconnectedEventHandler(rdpContext* context, ChannelC
 		if (rfi->settings->SoftwareGdi)
 			gdi_graphics_pipeline_uninit(context->gdi, (RdpgfxClientContext*) e->pInterface);
 	}
-	remmina_plugin_service->log_printf("Channel %s has been closed\n", e->name);
+	REMMINA_PLUGIN_DEBUG("Channel %s has been closed", e->name);
 
 }
