@@ -44,12 +44,13 @@
 #include <cairo/cairo-xlib.h>
 #include <freerdp/locale/keyboard.h>
 
-static void remmina_rdp_event_on_focus_in(GtkWidget* widget, GdkEventKey* event, RemminaProtocolWidget* gp)
+static gboolean remmina_rdp_event_on_focus_in(GtkWidget* widget, GdkEventKey* event, RemminaProtocolWidget* gp)
 {
 	TRACE_CALL(__func__);
 	rfContext* rfi = GET_PLUGIN_DATA(gp);
 	rdpInput* input;
 	GdkModifierType state;
+
 #if GTK_CHECK_VERSION(3, 20, 0)
 	GdkSeat *seat;
 #else
@@ -58,7 +59,7 @@ static void remmina_rdp_event_on_focus_in(GtkWidget* widget, GdkEventKey* event,
 	GdkDevice *keyboard = NULL;
 
 	if (!rfi || !rfi->connected || rfi->is_reconnecting)
-		return;
+		return FALSE;
 
 	input = rfi->instance->input;
 	UINT32 toggle_keys_state = 0;
@@ -84,6 +85,8 @@ static void remmina_rdp_event_on_focus_in(GtkWidget* widget, GdkEventKey* event,
 
 	input->SynchronizeEvent(input, toggle_keys_state);
 	input->KeyboardEvent(input, KBD_FLAGS_RELEASE, 0x0F);
+
+	return FALSE;
 }
 
 void remmina_rdp_event_event_push(RemminaProtocolWidget* gp, const RemminaPluginRdpEvent* e)
@@ -542,7 +545,7 @@ static gboolean remmina_rdp_event_on_scroll(GtkWidget* widget, GdkEventScroll* e
 		flag = PTR_FLAGS_WHEEL | PTR_FLAGS_WHEEL_NEGATIVE | 0x0088;
 		break;
 
-#ifdef GDK_SCROLL_SMOOTH
+#if GTK_CHECK_VERSION(3, 4, 0)
 	case GDK_SCROLL_SMOOTH:
 		if (event->delta_y < 0)
 			flag = PTR_FLAGS_WHEEL | 0x0078;
@@ -714,7 +717,7 @@ gboolean remmina_rdp_event_on_clipboard(GtkClipboard *gtkClipboard, GdkEvent *ev
 	 * after receivina a RDP server format list in remmina_rdp_cliprdr_server_format_list()
 	 * In the latter case, we must ignore owner change */
 
-	g_debug("[RDP] owner-change event received");
+	REMMINA_PLUGIN_DEBUG("owner-change event received");
 
 	rfContext *rfi = GET_PLUGIN_DATA(gp);
 	if (rfi)
@@ -723,7 +726,7 @@ gboolean remmina_rdp_event_on_clipboard(GtkClipboard *gtkClipboard, GdkEvent *ev
 	if (gtk_clipboard_get_owner(gtkClipboard) != (GObject*)gp) {
 		/* To do: avoid this when the new owner is another remmina protocol widget of
 		 * the same remmina application */
-		g_debug("[RDP]     new owner is different than me: new=%p me=%p. Sending local clipboard format list to server.",
+		REMMINA_PLUGIN_DEBUG("     new owner is different than me: new=%p me=%p. Sending local clipboard format list to server.",
 				gtk_clipboard_get_owner(gtkClipboard), (GObject*)gp);
 
 		pFormatList = remmina_rdp_cliprdr_get_client_format_list(gp);
@@ -731,7 +734,7 @@ gboolean remmina_rdp_event_on_clipboard(GtkClipboard *gtkClipboard, GdkEvent *ev
 		rdp_event.clipboard_formatlist.pFormatList = pFormatList;
 		remmina_rdp_event_event_push(gp, &rdp_event);
 	} else {
-		g_debug("[RDP]    ... but I'm the owner!");
+		REMMINA_PLUGIN_DEBUG("    ... but I'm the owner!");
 	}
 	return TRUE;
 }
@@ -752,8 +755,13 @@ void remmina_rdp_event_init(RemminaProtocolWidget* gp)
 	gtk_widget_show(rfi->drawing_area);
 	gtk_container_add(GTK_CONTAINER(gp), rfi->drawing_area);
 
-	gtk_widget_add_events(rfi->drawing_area, GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK
-		| GDK_BUTTON_RELEASE_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK | GDK_SCROLL_MASK | GDK_FOCUS_CHANGE_MASK);
+	gtk_widget_add_events(rfi->drawing_area, GDK_POINTER_MOTION_MASK 
+		| GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK 
+		| GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK 
+#if GTK_CHECK_VERSION(3,4,0)
+		| GDK_SMOOTH_SCROLL_MASK 
+#endif
+		| GDK_SCROLL_MASK | GDK_FOCUS_CHANGE_MASK);
 	gtk_widget_set_can_focus(rfi->drawing_area, TRUE);
 
 	remmina_plugin_service->protocol_plugin_register_hostkey(gp, rfi->drawing_area);
@@ -948,7 +956,7 @@ void remmina_rdp_event_update_scale(RemminaProtocolWidget* gp)
 		remmina_rdp_event_create_cairo_surface(rfi);
 	}
 
-	/* Send gdi->width and gdi->height obtanied from remote server to gp plugin,
+	/* Send gdi->width and gdi->height obtained from remote server to gp plugin,
 	 * so they will be saved when closing connection */
 	if (width != gdi->width)
 		remmina_plugin_service->protocol_plugin_set_width(gp, gdi->width);
@@ -981,7 +989,7 @@ static void remmina_rdp_event_connected(RemminaProtocolWidget* gp, RemminaPlugin
 	gtk_widget_queue_draw_area(rfi->drawing_area, 0, 0, gdi->width, gdi->height);
 
 	remmina_rdp_event_update_scale(gp);
-    
+
     remmina_plugin_service->protocol_plugin_signal_connection_opened(gp);
 }
 
@@ -1001,12 +1009,12 @@ static BOOL remmina_rdp_event_create_cursor(RemminaProtocolWidget* gp, RemminaPl
 	cairo_surface_t* surface;
 	UINT8* data = malloc(pointer->width * pointer->height * 4);
 
-	if (freerdp_image_copy_from_pointer_data(
+	if (!freerdp_image_copy_from_pointer_data(
 		    (BYTE*)data, PIXEL_FORMAT_BGRA32,
 		    pointer->width * 4, 0, 0, pointer->width, pointer->height,
 		    pointer->xorMaskData, pointer->lengthXorMask,
 		    pointer->andMaskData, pointer->lengthAndMask,
-		    pointer->xorBpp, &(ui->cursor.context->gdi->palette)) < 0) {
+		    pointer->xorBpp, &(ui->cursor.context->gdi->palette))) {
 		free(data);
 		return FALSE;
 	}
