@@ -54,7 +54,7 @@ typedef struct _RemminaPluginVncData {
 	gboolean		connected;
 	/* Whether the vnc process is running */
 	gboolean		running;
-	/* Whether the initialzation calls the authentication process */
+	/* Whether the initialization calls the authentication process */
 	gboolean		auth_called;
 	/* Whether it is the first attempt for authentication. Only first attempt will try to use cached credentials */
 	gboolean		auth_first;
@@ -67,7 +67,7 @@ typedef struct _RemminaPluginVncData {
 	guint			queuedraw_handler;
 
 	gulong			clipboard_handler;
-	GTimeVal		clipboard_timer;
+	GDateTime		*clipboard_timer;
 
 	cairo_surface_t *	queuecursor_surface;
 	gint			queuecursor_x, queuecursor_y;
