@@ -47,6 +47,9 @@ typedef enum {
 	WWW_WEB_VIEW_DOCUMENT_OTHER
 } WWWWebViewDocumentType;
 
+extern RemminaPluginService *remmina_plugin_service;
+#define REMMINA_PLUGIN_DEBUG(fmt, ...) remmina_plugin_service->_remmina_debug(__func__, fmt, ##__VA_ARGS__)
+
 
 G_BEGIN_DECLS
 void remmina_plugin_www_decide_nav(WebKitPolicyDecision *decision, RemminaProtocolWidget *gp);
