@@ -110,8 +110,6 @@ struct _RemminaFileEditorPriv {
 	GtkWidget *		name_entry;
 	GtkWidget *		group_combo;
 	GtkWidget *		protocol_combo;
-	GtkWidget *		precommand_entry;
-	GtkWidget *		postcommand_entry;
 	GtkWidget *		save_button;
 
 	GtkWidget *		config_box;
@@ -126,6 +124,10 @@ struct _RemminaFileEditorPriv {
 	GtkWidget *		resolution_custom_combo;
 	GtkWidget *		keymap_combo;
 
+	GtkWidget *		behavior_autostart_check;
+	GtkWidget *		behavior_precommand_entry;
+	GtkWidget *		behavior_postcommand_entry;
+
 	GtkWidget *		ssh_tunnel_enabled_check;
 	GtkWidget *		ssh_tunnel_loopback_check;
 	GtkWidget *		ssh_tunnel_server_default_radio;
@@ -359,7 +361,7 @@ static void remmina_file_editor_create_ssh_privatekey(RemminaFileEditor *gfe, Gt
 	RemminaFileEditorPriv *priv = gfe->priv;
 
 	widget = gtk_radio_button_new_with_label_from_widget(
-		GTK_RADIO_BUTTON(priv->ssh_tunnel_auth_password_radio), _("SSH identity file"));
+		GTK_RADIO_BUTTON(priv->ssh_tunnel_auth_agent_radio), _("SSH identity file"));
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(remmina_file_editor_ssh_tunnel_auth_publickey_radio_on_toggled), gfe);
 	priv->ssh_tunnel_auth_publickey_radio = widget;
@@ -582,8 +584,8 @@ static void remmina_file_editor_create_resolution(RemminaFileEditor *gfe, const
 	g_free(res_str);
 }
 
-static GtkWidget *remmina_file_editor_create_text(RemminaFileEditor *gfe, GtkWidget *grid,
-						  gint row, gint col, const gchar *label, const gchar *value)
+static GtkWidget *remmina_file_editor_create_text2(RemminaFileEditor *gfe, GtkWidget *grid,
+						  gint row, gint col, const gchar *label, const gchar *value, gint left, gint right)
 {
 	TRACE_CALL(__func__);
 	GtkWidget *widget;
@@ -591,17 +593,19 @@ static GtkWidget *remmina_file_editor_create_text(RemminaFileEditor *gfe, GtkWid
 	widget = gtk_label_new(label);
 	gtk_widget_show(widget);
 #if GTK_CHECK_VERSION(3, 12, 0)
-	gtk_widget_set_margin_end(widget, 40);
+	gtk_widget_set_margin_start(widget, left);
+	gtk_widget_set_margin_end(widget, right);
 #else
-	gtk_widget_set_margin_right(widget, 40);
+	gtk_widget_set_margin_left(widget, left);
+	gtk_widget_set_margin_right(widget, right);
 #endif
 	gtk_widget_set_valign(widget, GTK_ALIGN_START);
 	gtk_widget_set_halign(widget, GTK_ALIGN_START);
-	gtk_grid_attach(GTK_GRID(grid), widget, 0, row, 1, 1);
+	gtk_grid_attach(GTK_GRID(grid), widget, col, row, 1, 1);
 
 	widget = gtk_entry_new();
 	gtk_widget_show(widget);
-	gtk_grid_attach(GTK_GRID(grid), widget, 1, row, 1, 1);
+	gtk_grid_attach(GTK_GRID(grid), widget, col + 1, row, 1, 1);
 	gtk_entry_set_max_length(GTK_ENTRY(widget), 300);
 	gtk_widget_set_hexpand(widget, TRUE);
 
@@ -611,6 +615,43 @@ static GtkWidget *remmina_file_editor_create_text(RemminaFileEditor *gfe, GtkWid
 	return widget;
 }
 
+static GtkWidget *remmina_file_editor_create_text(RemminaFileEditor *gfe, GtkWidget *grid,
+						  gint row, gint col, const gchar *label, const gchar *value)
+{
+	TRACE_CALL(__func__);
+	return remmina_file_editor_create_text2(gfe, grid, row, col, label, value, 0, 40);
+}
+
+static GtkWidget *remmina_file_editor_create_textarea(RemminaFileEditor *gfe, GtkWidget *grid,
+						  gint row, gint col, const gchar *label, const gchar *value)
+{
+	TRACE_CALL(__func__);
+	GtkWidget *widget;
+	GtkTextView *view;
+	GtkTextBuffer *buffer;
+	GtkTextIter start;
+
+	widget = gtk_text_view_new();
+	view = GTK_TEXT_VIEW (widget);
+	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (view), GTK_WRAP_WORD);
+	gtk_text_view_set_top_margin (GTK_TEXT_VIEW (view), 20);
+	gtk_text_view_set_bottom_margin (GTK_TEXT_VIEW (view), 20);
+	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (view), 20);
+	gtk_text_view_set_right_margin (GTK_TEXT_VIEW (view), 20);
+	gtk_text_view_set_monospace(view, TRUE);
+	if (value) {
+		buffer = gtk_text_view_get_buffer (view);
+		gtk_text_buffer_set_text (buffer, value, -1);
+		gtk_text_buffer_get_start_iter (buffer, &start);
+		gtk_text_buffer_place_cursor(buffer, &start);
+	}
+	gtk_widget_show(widget);
+	gtk_widget_set_hexpand(widget, TRUE);
+	gtk_widget_set_size_request (GTK_WIDGET(view), 320, 300);
+	gtk_grid_attach(GTK_GRID(grid), widget, 0, row, 1, 1);
+	return widget;
+}
+
 static GtkWidget *remmina_file_editor_create_select(RemminaFileEditor *gfe, GtkWidget *grid,
 						    gint row, gint col, const gchar *label, const gpointer *list, const gchar *value)
 {
@@ -657,7 +698,6 @@ static GtkWidget *remmina_file_editor_create_check(RemminaFileEditor *gfe, GtkWi
 	GtkWidget *widget;
 	widget = gtk_check_button_new_with_label(label);
 	gtk_widget_show(widget);
-	gtk_grid_set_row_spacing(GTK_GRID(grid), 1);
 	gtk_grid_attach(GTK_GRID(grid), widget, top, row, 1, 1);
 
 	if (value)
@@ -712,7 +752,7 @@ static void remmina_file_editor_create_settings(RemminaFileEditor *gfe, GtkWidge
 	gint grid_column = 0;
 	gchar **strarr;
 	gchar *setting_name;
-
+	const gchar *escaped;
 
 	while (settings->type != REMMINA_PROTOCOL_SETTING_TYPE_END) {
 		setting_name = (gchar *)(remmina_plugin_manager_get_canonical_setting_name(settings));
@@ -754,6 +794,15 @@ static void remmina_file_editor_create_settings(RemminaFileEditor *gfe, GtkWidge
 			grid_row++;
 			break;
 
+		case REMMINA_PROTOCOL_SETTING_TYPE_TEXTAREA:
+			escaped = remmina_file_get_string(priv->remmina_file, setting_name);
+			escaped = g_uri_unescape_string (escaped, NULL);
+			widget = remmina_file_editor_create_textarea(gfe, grid, grid_row, 0,
+								 g_dgettext(priv->plugin->domain, settings->label), escaped);
+			g_hash_table_insert(priv->setting_widgets, setting_name, widget);
+			grid_row++;
+			break;
+
 		case REMMINA_PROTOCOL_SETTING_TYPE_SELECT:
 			widget = remmina_file_editor_create_select(gfe, grid, grid_row, 0,
 								   g_dgettext(priv->plugin->domain, settings->label),
@@ -820,6 +869,42 @@ static void remmina_file_editor_create_settings(RemminaFileEditor *gfe, GtkWidge
 	}
 }
 
+static void remmina_file_editor_create_behavior_tab(RemminaFileEditor *gfe)
+{
+	TRACE_CALL(__func__);
+	RemminaFileEditorPriv *priv = gfe->priv;
+	GtkWidget *grid;
+	GtkWidget *widget;
+	const gchar *cs;
+
+	/* The Behavior tab (implementation) */
+	grid = remmina_file_editor_create_notebook_tab(gfe, NULL, _("Behavior"),  20, 2);
+
+	/* Execute Command frame */
+	remmina_public_create_group(GTK_GRID(grid), _("Execute a Command"), 0, 1, 2);
+
+	/* PRE connection command */
+	cs = remmina_file_get_string(priv->remmina_file, "precommand");
+	widget = remmina_file_editor_create_text2(gfe, grid, 2, 0, _("Before connecting"), cs, 24, 26);
+	priv->behavior_precommand_entry = widget;
+	gtk_entry_set_placeholder_text(GTK_ENTRY(widget), _("command %h %u %t %U %p %g --option"));
+	gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
+
+	/* POST connection command */
+	cs = remmina_file_get_string(priv->remmina_file, "postcommand");
+	widget = remmina_file_editor_create_text2(gfe, grid, 3, 0, _("After connecting"), cs, 24, 16);
+	priv->behavior_postcommand_entry = widget;
+	gtk_entry_set_placeholder_text(GTK_ENTRY(widget), _("/path/to/command -opt1 arg %h %u %t -opt2 %U %p %g"));
+	gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
+
+	/* Startup frame */
+	remmina_public_create_group(GTK_GRID(grid), _("Startup"), 4, 1, 2);
+
+	/* Autostart profile option */
+	remmina_file_editor_create_check(gfe, grid, 6, 1, _("Autostart this profile"),
+							remmina_file_get_int(priv->remmina_file, "enable-autostart", FALSE));
+}
+
 static void remmina_file_editor_create_ssh_tunnel_tab(RemminaFileEditor *gfe, RemminaProtocolSSHSetting ssh_setting)
 {
 	TRACE_CALL(__func__);
@@ -937,7 +1022,7 @@ static void remmina_file_editor_create_ssh_tunnel_tab(RemminaFileEditor *gfe, Re
 	row++;
 
 	widget = gtk_radio_button_new_with_label_from_widget(
-		GTK_RADIO_BUTTON(priv->ssh_tunnel_auth_password_radio), _("Public key (automatic)"));
+		GTK_RADIO_BUTTON(priv->ssh_tunnel_auth_agent_radio), _("Public key (automatic)"));
 	gtk_grid_attach(GTK_GRID(grid), widget, 0, row + 22, 1, 1);
 	priv->ssh_tunnel_auth_auto_publickey_radio = widget;
 	row++;
@@ -948,7 +1033,6 @@ static void remmina_file_editor_create_ssh_tunnel_tab(RemminaFileEditor *gfe, Re
 
 	widget = gtk_label_new(_("Password to unlock private key"));
 	gtk_grid_attach(GTK_GRID(grid), widget, 0, row + 23, 1, 1);
-	priv->ssh_tunnel_auth_password_radio = widget;
 	widget = gtk_entry_new();
 	gtk_grid_attach(GTK_GRID(grid), widget, 1, row + 23, 2, 1);
 	gtk_entry_set_max_length(GTK_ENTRY(widget), 300);
@@ -979,14 +1063,26 @@ static void remmina_file_editor_create_ssh_tunnel_tab(RemminaFileEditor *gfe, Re
 	}
 
 	//if (!(g_strcmp0(p, "SFTP") == 0 || g_strcmp0(p, "SSH") == 0)) {
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
-					     remmina_file_get_int(priv->remmina_file, "ssh_tunnel_auth", 0) == SSH_AUTH_PUBLICKEY ?
-					     priv->ssh_tunnel_auth_publickey_radio :
-					     remmina_file_get_int(priv->remmina_file, "ssh_tunnel_auth", 0) == SSH_AUTH_AUTO_PUBLICKEY ?
-					     priv->ssh_tunnel_auth_auto_publickey_radio :
-					     remmina_file_get_int(priv->remmina_file, "ssh_tunnel_auth", 0) == SSH_AUTH_AGENT ?
-					     priv->ssh_tunnel_auth_agent_radio :
-					     priv->ssh_tunnel_auth_password_radio), TRUE);
+	gint ssh_tunnel_auth_status = remmina_file_get_int(priv->remmina_file, "ssh_tunnel_auth", 0);
+	g_debug ("[Editor - tunnel] ssh_tunnel_auth_status is: %d", ssh_tunnel_auth_status);
+	switch (ssh_tunnel_auth_status) {
+		case SSH_AUTH_PUBLICKEY:
+			g_debug("[Editor - tunnel] Auth set from file to SSH_AUTH_PUBLICKEY");
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->ssh_tunnel_auth_publickey_radio), TRUE);
+			break;
+		case SSH_AUTH_AUTO_PUBLICKEY:
+			g_debug("[Editor - tunnel] Auth set from file to SSH_AUTH_AUTO_PUBLICKEY");
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->ssh_tunnel_auth_auto_publickey_radio), TRUE);
+			break;
+		case SSH_AUTH_AGENT:
+			g_debug("[Editor - tunnel] Auth set from file to SSH_AUTH_AGENT");
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->ssh_tunnel_auth_agent_radio), TRUE);
+			break;
+		default:
+			g_debug("[Editor - tunnel] Auth set from file to SSH_AUTH_PASSWORD");
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->ssh_tunnel_auth_password_radio), TRUE);
+			break;
+	}
 
 	remmina_file_editor_ssh_tunnel_enabled_check_on_toggled(NULL, gfe, ssh_setting);
 	//}
@@ -1001,10 +1097,10 @@ static void remmina_file_editor_create_all_settings(RemminaFileEditor *gfe)
 	RemminaFileEditorPriv *priv = gfe->priv;
 	GtkWidget *grid;
 
-	static const RemminaProtocolSetting autostart_settings[] =
+	static const RemminaProtocolSetting notes_settings[] =
 	{
-		{ REMMINA_PROTOCOL_SETTING_TYPE_CHECK, "enable-autostart", N_("Turn on \"Autostart\" for this profile"), FALSE, NULL, NULL },
-		{ REMMINA_PROTOCOL_SETTING_TYPE_END,   NULL,		   NULL,					 FALSE, NULL, NULL }
+		{ REMMINA_PROTOCOL_SETTING_TYPE_TEXTAREA, "notes_text", NULL, FALSE, NULL, NULL },
+		{ REMMINA_PROTOCOL_SETTING_TYPE_END,   NULL,		   NULL, FALSE, NULL, NULL }
 	};
 
 	remmina_file_editor_create_notebook_container(gfe);
@@ -1021,12 +1117,15 @@ static void remmina_file_editor_create_all_settings(RemminaFileEditor *gfe)
 		remmina_file_editor_create_settings(gfe, grid, priv->plugin->advanced_settings);
 	}
 
-	/* Autostart tab */
-	grid = remmina_file_editor_create_notebook_tab(gfe, NULL, _("Autostart"), 20, 2);
-	remmina_file_editor_create_settings(gfe, grid, autostart_settings);
+	/* The Behavior tab */
+	remmina_file_editor_create_behavior_tab(gfe);
 
 	/* The SSH tab */
 	remmina_file_editor_create_ssh_tunnel_tab(gfe, priv->plugin->ssh_setting);
+
+	/* Notes tab */
+	grid = remmina_file_editor_create_notebook_tab(gfe, NULL, _("Notes"), 1, 1);
+	remmina_file_editor_create_settings(gfe, grid, notes_settings);
 }
 
 static void remmina_file_editor_protocol_combo_on_changed(GtkComboBox *combo, RemminaFileEditor *gfe)
@@ -1074,6 +1173,20 @@ static void remmina_file_editor_protocol_combo_on_changed(GtkComboBox *combo, Re
 	}
 }
 
+static void remmina_file_editor_save_behavior_tab(RemminaFileEditor *gfe)
+{
+	TRACE_CALL(__func__);
+	RemminaFileEditorPriv *priv = gfe->priv;
+	gboolean autostart_enabled;
+
+	remmina_file_set_string(priv->remmina_file, "precommand", gtk_entry_get_text(GTK_ENTRY(priv->behavior_precommand_entry)));
+	remmina_file_set_string(priv->remmina_file, "postcommand", gtk_entry_get_text(GTK_ENTRY(priv->behavior_postcommand_entry)));
+
+	autostart_enabled = (priv->behavior_autostart_check ?
+			      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(priv->behavior_autostart_check)) : FALSE);
+	remmina_file_set_int(priv->remmina_file, "enable-autostart", autostart_enabled);
+}
+
 static void remmina_file_editor_save_ssh_tunnel_tab(RemminaFileEditor *gfe)
 {
 	TRACE_CALL(__func__);
@@ -1142,11 +1255,22 @@ static void remmina_file_editor_update_settings(RemminaFileEditor *gfe)
 	RemminaFileEditorPriv *priv = gfe->priv;
 	GHashTableIter iter;
 	gpointer key, value;
+	GtkTextBuffer *buffer;
+	gchar *escaped, *unescaped;
+	GtkTextIter start, end;
 
 	g_hash_table_iter_init(&iter, priv->setting_widgets);
 	while (g_hash_table_iter_next(&iter, &key, &value)) {
 		if (GTK_IS_ENTRY(value)) {
 			remmina_file_set_string(priv->remmina_file, (gchar *)key, gtk_entry_get_text(GTK_ENTRY(value)));
+		} else if (GTK_IS_TEXT_VIEW(value)) {
+			buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(value));
+			gtk_text_buffer_get_start_iter (buffer, &start);
+			gtk_text_buffer_get_end_iter (buffer, &end);
+			unescaped = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
+			escaped = g_uri_escape_string (unescaped, NULL, TRUE);
+			remmina_file_set_string(priv->remmina_file, (gchar *)key, escaped);
+			g_free(escaped);
 		} else if (GTK_IS_COMBO_BOX(value)) {
 			remmina_file_set_string_ref(priv->remmina_file, (gchar *)key,
 						    remmina_public_combo_get_active_text(GTK_COMBO_BOX(value)));
@@ -1181,9 +1305,6 @@ static void remmina_file_editor_update(RemminaFileEditor *gfe)
 	remmina_file_set_string_ref(priv->remmina_file, "protocol",
 				    remmina_public_combo_get_active_text(GTK_COMBO_BOX(priv->protocol_combo)));
 
-	remmina_file_set_string(priv->remmina_file, "precommand", gtk_entry_get_text(GTK_ENTRY(priv->precommand_entry)));
-	remmina_file_set_string(priv->remmina_file, "postcommand", gtk_entry_get_text(GTK_ENTRY(priv->postcommand_entry)));
-
 	remmina_file_set_string_ref(priv->remmina_file, "server",
 				    (priv->server_combo ? remmina_public_combo_get_active_text(GTK_COMBO_BOX(priv->server_combo)) : NULL));
 
@@ -1214,6 +1335,7 @@ static void remmina_file_editor_update(RemminaFileEditor *gfe)
 		remmina_file_set_string_ref(priv->remmina_file, "keymap",
 					    remmina_public_combo_get_active_text(GTK_COMBO_BOX(priv->keymap_combo)));
 
+	remmina_file_editor_save_behavior_tab(gfe);
 	remmina_file_editor_save_ssh_tunnel_tab(gfe);
 	remmina_file_editor_update_settings(gfe);
 }
@@ -1498,42 +1620,6 @@ GtkWidget *remmina_file_editor_new_from_file(RemminaFile *remminafile)
 	remmina_plugin_manager_for_each_plugin(REMMINA_PLUGIN_TYPE_PROTOCOL, remmina_file_editor_iterate_protocol, gfe);
 	g_signal_connect(G_OBJECT(widget), "changed", G_CALLBACK(remmina_file_editor_protocol_combo_on_changed), gfe);
 
-	/* Prior connection command */
-	widget = gtk_label_new(_("Pre-command"));
-	gtk_widget_show(widget);
-	gtk_widget_set_valign(widget, GTK_ALIGN_START);
-	gtk_widget_set_halign(widget, GTK_ALIGN_START);
-	gtk_grid_attach(GTK_GRID(grid), widget, 0, 12, 3, 1);
-	gtk_grid_set_column_spacing(GTK_GRID(grid), 10);
-
-	widget = gtk_entry_new();
-	gtk_widget_show(widget);
-	gtk_grid_attach(GTK_GRID(grid), widget, 1, 12, 3, 1);
-	gtk_entry_set_max_length(GTK_ENTRY(widget), 200);
-	priv->precommand_entry = widget;
-	cs = remmina_file_get_string(remminafile, "precommand");
-	gtk_entry_set_text(GTK_ENTRY(widget), cs ? cs : "");
-	gtk_entry_set_placeholder_text(GTK_ENTRY(widget), "command %h %u %t %U %p %g --option");
-	gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
-
-	/* POST connection command */
-	widget = gtk_label_new(_("Post-command"));
-	gtk_widget_show(widget);
-	gtk_widget_set_valign(widget, GTK_ALIGN_START);
-	gtk_widget_set_halign(widget, GTK_ALIGN_START);
-	gtk_grid_attach(GTK_GRID(grid), widget, 0, 15, 3, 1);
-	gtk_grid_set_column_spacing(GTK_GRID(grid), 10);
-
-	widget = gtk_entry_new();
-	gtk_widget_show(widget);
-	gtk_grid_attach(GTK_GRID(grid), widget, 1, 15, 3, 1);
-	gtk_entry_set_max_length(GTK_ENTRY(widget), 200);
-	priv->postcommand_entry = widget;
-	cs = remmina_file_get_string(remminafile, "postcommand");
-	gtk_entry_set_text(GTK_ENTRY(widget), cs ? cs : "");
-	gtk_entry_set_placeholder_text(GTK_ENTRY(widget), "/path/to/command -opt1 arg %h %u %t -opt2 %U %p %g");
-	gtk_widget_set_tooltip_markup(widget, _(cmd_tips));
-
 	/* Create the "Preference" frame */
 	widget = gtk_event_box_new();
 	gtk_widget_show(widget);
