@@ -37,7 +37,7 @@
 #pragma once
 
 /*
- * Remmina Perference Loader
+ * Remmina Preference Loader
  */
 
 G_BEGIN_DECLS
@@ -169,6 +169,8 @@ typedef struct _RemminaPref {
 	guint			vte_shortcutkey_copy;
 	guint			vte_shortcutkey_paste;
 	guint			vte_shortcutkey_select_all;
+	guint			vte_shortcutkey_increase_font;
+	guint			vte_shortcutkey_decrease_font;
 	/* In View menu */
 	gboolean		hide_toolbar;
 	gboolean		small_toolbutton;
@@ -203,6 +205,7 @@ typedef struct _RemminaPref {
 	gchar *			last_success;
 
 	/* Remmina news */
+	gboolean		periodic_news_permitted;
 	glong			periodic_rmnews_last_get;
 	glong			periodic_rmnews_get_count;
 	gchar *			periodic_rmnews_uuid_prefix;
